package com.goldenwater.slaj.eme.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.goldenwater.slaj.eme.domain.BusiTrainRecord;

/**
 * 应急预案培训记录 数据层
 */
@Mapper
public interface BusiTrainRecordMapper {

    /**
     * 查询应急预案培训记录
     * @param guid 查询条件
     * @return 应急预案培训记录
     */
    BusiTrainRecord selectBusiTrainRecordByGuid(String guid);

    /**
     * 查询应急预案培训记录列表
     * @param busiTrainRecord 查询条件
     * @return 应急预案培训记录集合
     */
    List<BusiTrainRecord> selectBusiTrainRecordList(BusiTrainRecord busiTrainRecord);

    /**
     * 新增应急预案培训记录
     * @param busiTrainRecord 应急预案培训记录
     * @return 影响行数
     */
    int insertBusiTrainRecord(BusiTrainRecord busiTrainRecord);

    /**
     * 修改应急预案培训记录
     * @param busiTrainRecord 应急预案培训记录
     * @return 影响行数
     */
    int updateBusiTrainRecord(BusiTrainRecord busiTrainRecord);

    /**
     * 删除应急预案培训记录
     * @param guid 主键
     * @return 影响行数
     */
    int deleteBusiTrainRecordByGuid(String guid);

    /**
     * 批量删除应急预案培训记录
     * @param guids 主键数组
     * @return 影响行数
     */
    int deleteBusiTrainRecordByGuids(String[] guids);
}
